import unittest
import numpy as np
from NavierStokes.TDMAsolver import TDMAsolver

class Test_test(unittest.TestCase):

    def test(self):
        ##For checking purposes using the example given in class
        aa = np.array([-5., -5., -5., -5.])  # diagonal column below the middle
        bb = np.array([20., 15., 15., 15., 10.])  # middle diagonal column value
        cc = np.array([-5., -5., -5., -5.])  # diagonal column above the middle
        dd = np.array([1100., 100., 100., 100., 100.])  # the right column (b)
        self.assertEqual(np.round(TDMAsolver(aa, bb, cc, dd),2)[0],64.23)
        self.assertEqual(np.round(TDMAsolver(aa, bb, cc, dd),2)[1],36.91)
        self.assertEqual(np.round(TDMAsolver(aa, bb, cc, dd),2)[2],26.50)
        self.assertEqual(np.round(TDMAsolver(aa, bb, cc, dd),2)[3],22.60)
        self.assertEqual(np.round(TDMAsolver(aa, bb, cc, dd),2)[4],21.30)

if __name__ == '__main__':
    unittest.main()



import unittest

from NavierStokes.test import test

class Test_test(unittest.TestCase):

    def test(self):
        self.assertEqual(test(),'test')
    def test2(self):
        self.assertEqual(test(),'t2')

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
"""
FILE TDMAsolver.py
Solves TDMA

Name: Kyu Mok Kim
Student Number: 998745381

MIE1210 Project 1

@author: kimkyu4

This code is designed to solve the system of equations denoted as: Ax=b,
using TDMA method using a,b,c,d arrays.
Refer to my report for detailed explanation.
"""

# importing numpy for convenience
import numpy as np


# TDMA Solver
def TDMAsolver(aa, bb, cc, dd):
    a, b, c, d = map(np.array, (aa, bb, cc, dd))  # preventing overwriting original
    n = len(b)  # number of rows/equations

    for i in range(1, n):
        e = a[i - 1] / b[i - 1]
        b[i] = b[i] - e * c[i - 1]
        d[i] = d[i] - e * d[i - 1]

    x = b
    x[-1] = d[-1] / b[-1]

    for j in range(n - 2, -1, -1):
        x[j] = (d[j] - c[j] * x[j + 1]) / b[j]

    return x



import argparse
from NavierStokes.test import test
from NavierStokes.TDMAsolver import TDMAsolver

def main():
    parser=argparse.ArgumentParser()
    parser.add_argument("-aa", help="diagonal column below the middle")
    parser.add_argument("-bb", help="middle diagonal column value")
    parser.add_argument("-cc", help="diagonal column above the middle")
    parser.add_argument("-dd", help="the right column (b)")
    parser.add_argument("-td","--tdma", help="TDMA solver", action="store_true")
    parser.add_argument("-t", help="just a test")
    a = parser.parse_args()

    if a.t:
        test()
    elif a.tdma:
        TDMAsolver(a.aa,a.bb,a.cc,a.dd)



from setuptools import setup, find_packages
from NavierStokes import __version__
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

setup(
    name='NavierStokes',
    version=__version__,
    author='Kyu Mok (Ricky) Kim',
    author_email='rickykim93@hotmail.com',
    url='http://rickykim.net',
    description='Navier Stokes Calculator',
    long_description=open(path.join(here, 'README.md'), encoding='utf-8').read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[
        'numpy',
        'pandas',
        'scipy',
    ],
    test_suite='tests',
    entry_points={
        'console_scripts': [
            'NavierStokes = NavierStokes.__main__:main',
        ]
    }
)
